﻿using Infragistics.Windows.Ribbon;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace WpfControlsSample
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : XamRibbonWindow
	{
		private MainViewModel _vm;

		public MainWindow()
		{
			this.DataContext = _vm = new MainViewModel();

			InitializeComponent();
		}
	}

	public class ViewModelBase : INotifyPropertyChanged
	{
		protected void SetField<T>(ref T member, T newValue, [CallerMemberName]string propertyName = null)
		{
			if (!EqualityComparer<T>.Default.Equals(member, newValue))
			{
				member = newValue;
				this.OnPropertyChanged(propertyName);
			}
		}

		protected void OnPropertyChanged([CallerMemberName]string propertyName = null)
		{
			var handler = this.PropertyChanged;

			if (handler != null)
				handler(this, new PropertyChangedEventArgs(propertyName));
		}

		public event PropertyChangedEventHandler PropertyChanged;
	}

	public class Settings1 : ViewModelBase
	{
		private bool _isBeingUsed;
		public bool IsBeingUsed
		{
			get { return _isBeingUsed; }
			set { this.SetField(ref _isBeingUsed, value); }
		}
	}

	public class Settings2 : ViewModelBase
	{
		private string _name;
		public string Name
		{
			get { return _name; }
			set { this.SetField(ref _name, value); }
		}
	}

	public class MainViewModel : ViewModelBase
	{
		private readonly Settings1 _settings1;
		private readonly Settings2 _settings2;

		public MainViewModel()
		{
			_settings1 = new Settings1() { IsBeingUsed = true };
			_settings2 = new Settings2() { Name = Environment.UserName };
		}

		public Settings1 Settings1Object
		{
			get { return _settings1; }
		}

		public Settings2 Settings2Object
		{
			get { return _settings2; }
		}

	}
}
